﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Events;
using Infragistics.UltraChart.Core;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Resources;
using System.Collections;

namespace ChartSample
{
    public partial class Form1 : Form
    {
        IAdvanceAxis XAxis { get; set; }
        IAdvanceAxis YAxis { get; set; }
       static string currentY = "";
        public Form1()
        {
            InitializeComponent();
            Hashtable labelHash = new Hashtable();
            labelHash.Add("CUSTOM", new MyLabelRenderer());
            chartLines.LabelHash = labelHash;
            chartLines.Tooltips.FormatString = "<CUSTOM>";
            chartLines.EnableCrossHair = false;
 
        }

        void chartLines_FillSceneGraph(object sender, FillSceneGraphEventArgs e)
        {
            PrimitiveCollection primitivesToAdd = new PrimitiveCollection();
            foreach (Primitive p in e.SceneGraph)
            {
                Polygon oly = p as Polygon;
                if (oly != null)
                {
                    var gpth = new System.Drawing.Drawing2D.GraphicsPath();
                    Point[] points = new Point[oly.DataPoints.Length];

                    for (int current = 0; current < oly.DataPoints.Length; current++)
                    {
                        points[current] = oly.DataPoints[current].point;
                    }
                    gpth.AddPolygon(points);
                    Path pathPrimitive = new Path();
                    pathPrimitive.GraphicsPath = gpth;
                    pathPrimitive.Row = oly.Row;
                    pathPrimitive.Column = 0;
                    pathPrimitive.PE.FillOpacity = pathPrimitive.PE.StrokeOpacity = 0;
                    pathPrimitive.Caps = PCaps.HitTest | PCaps.Tooltip | PCaps.SkinStrokeOnly;
                    pathPrimitive.Layer = oly.Layer;
                    pathPrimitive.Chart = oly.Chart;
                    primitivesToAdd.Add(pathPrimitive);
                }
            }
            e.SceneGraph.AddRange(primitivesToAdd.ToArray());

            this.XAxis = e.Grid["X"] as IAdvanceAxis;
            this.YAxis = e.Grid["Y"] as IAdvanceAxis;

        }

        private void ultraChart1_MouseMove(object sender, MouseEventArgs e)
        {
            if (this.XAxis == null || this.YAxis == null)
            {
                return;
            }
            object xValue = this.XAxis.MapInverse(e.X);
            object yValue = this.YAxis.MapInverse(e.Y);
            currentY  =  yValue.ToString();
        }


        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox1.Checked)
                chartLines.FillSceneGraph += new FillSceneGraphEventHandler(chartLines_FillSceneGraph);
            else
                chartLines.FillSceneGraph -= new FillSceneGraphEventHandler(chartLines_FillSceneGraph);
            AddDataToTable(DateTime.Now);
        }

        private void Form1_Load(object sender, EventArgs e)
        {
          CreateDataTable();
            AddSeries();
            SetColors();
            AddRandomData();
        }

        private void SetColors()
        {
            var colors = new Color[] { Color.Red, Color.Yellow, Color.Lime, Color.Blue, Color.DarkGreen, Color.White, Color.Black };
            for (int i = 0; i < colors.Length; i++)
                chartLines.Series[i].PEs.Add(new PaintElement(colors[i]));
        }

        private void AddRandomData()
        {
            AddDataToTable(DateTime.Now.AddMinutes(-33));
            AddDataToTable(DateTime.Now.AddMinutes(-10));
            AddDataToTable(DateTime.Now.AddMinutes(-5));
            AddDataToTable(DateTime.Now);
        }

        private void AddSeries()
        {
            AddSeriesToChartLines("red");
            AddSeriesToChartLines("yellow");
            AddSeriesToChartLines("green");
            AddSeriesToChartLines("blue");
            AddSeriesToChartLines("green2");
            AddSeriesToChartLines("white");
            AddSeriesToChartLines("black");
        }

        public static System.Data.DataTable dataTable;
        private void CreateDataTable()
        {
            dataTable = new System.Data.DataTable();
            dataTable.Columns.Add("date", typeof(DateTime));
            dataTable.Columns.Add("datestr", typeof(String));
            dataTable.Columns.Add("red", typeof(int));
            dataTable.Columns.Add("yellow", typeof(int));
            dataTable.Columns.Add("green", typeof(int));
            dataTable.Columns.Add("blue", typeof(int));
            dataTable.Columns.Add("green2", typeof(int));
            dataTable.Columns.Add("white", typeof(int));
            dataTable.Columns.Add("black", typeof(int));
        }

        private void AddSeriesToChartLines(string name)
        {
            NumericTimeSeries series = new NumericTimeSeries();
            series.Data.DataSource = dataTable;
            series.Data.LabelColumn = "datestr";
            series.Data.TimeValueColumn = "date";
            series.Data.ValueColumn = name;
            series.Label = name;
            chartLines.Series.Add(series);
            series.DataBind();
        }

        Random rand = new Random();
        private void AddDataToTable(DateTime timeStamp)
        {
            dataTable.Rows.Add(timeStamp,
                timeStamp.ToString("HH:mm:ss"),
                rand.Next(10),
                rand.Next(10),
                rand.Next(10),
                rand.Next(10),
                rand.Next(10),
                rand.Next(10),
                rand.Next(10));

            foreach (NumericTimeSeries s in chartLines.Series)
                s.DataBind();
        }

        public class MyLabelRenderer : IRenderLabel
        {
            public string ToString(Hashtable context)
            {
                int row = (int)context["DATA_ROW"];
                int col = (int)context["DATA_COLUMN"];
                string customLabel = context["SERIES_LABEL"].ToString()+" : ";
                //use row and col to fetch an item from your dataset
               customLabel += Form1.currentY;


                return customLabel;
            }
        }


    }
}
